@@ -238,6 +238,7 @@ def create_ndf(data, sampling_rates, compressionbit=True, check_quality = True):
 # EMG-right, ECG, Airflow, Thor, Abdo, SpO2, Pressure and Corresponding sampling rates as a numpy array
 # a new dc-block filter is added now to EEG and ECG channels
 # we now also apply dc-block to respiratory channels but with cutoff f=0.05Hz
+# added eeg_raw to the spec which would include the raw eeg timeseries at 100Hz
 
     window_128 = np.hamming(128)
     window_256 = np.hamming(256)
@@ -528,6 +529,9 @@ def create_ndf(data, sampling_rates, compressionbit=True, check_quality = True):
     if data_exists[12]:    
         spec['pressure'] = processed_data[12]
 
+    if eeg is not None:
+        spec['eeg_raw'] = eeg
+
     
     payload = msgpack.packb(spec, use_single_float=True, use_bin_type=True) 
     shaHash = hashlib.sha1()
@@ -538,7 +542,7 @@ def create_ndf(data, sampling_rates, compressionbit=True, check_quality = True):
     urlSafeHash = base64.urlsafe_b64encode(("".join(map(chr, msgDigest))).encode('UTF-8')).decode('ascii')
     urlSafeHash = urlSafeHash[0:-1]
 
-    header = '{"version":"PSG", "revision": "2", "duration": '+ str(int(totalEpochs*30)) + ', "url":"' + urlSafeHash + '", "spec":' + json.dumps(list(spec.keys())) + '}'
+    header = '{"version":"PSG", "revision": "3", "duration": '+ str(int(totalEpochs*30)) + ', "url":"' + urlSafeHash + '", "spec":' + json.dumps(list(spec.keys())) + '}'
     header = '{:<256}'.format(header[:256])
     
     signature = bytearray(struct.pack('<3s?', b'NDF', compressionbit))  
